<!DOCTYPE html>
<html lang="en">
<head>
  {% block head %}
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <title>{{ title|default('Test Report') }}</title>
  <style>
    {% filter css_minify %}
    {% block style %}
    {{ get_ansi_styles(dark_bg=False)|join|safe }}
    {% include "html1/style.css" %}
    {% endblock %}
    {% endfilter %}
    </style>
    <script>
    {% block script %}
    {% include "html1/main.js" %}
    {% endblock %}
  </script>
  {% endblock %}
</head>
<body>
  <header>
    {% block header %}{% endblock %}
  </header>
  {% block content %}{% endblock %}
  <footer>
    {% block footer %}{% endblock %}
  </footer>
</body>
</html>
